; Add a radial blur effect.
;
; Distributed under GNU/GPL license
;
; v0.01 	- 16-Nov-03 - Works as intended, but lacking some options
;  0.01a 	- 16-Nov-03 - Now undo function works as a block
;  0.02		- 17-Nov-03 - Blur now centred on x,y coordinates instead of top left corner
;  0.03		            - Removed layering of effect, added feather option
;  0.04		            - Doubled radius figure for use as diameter in ellipse selection
;  0.05		- 26-Nov-03 - Removed automatic feathering/made feather variable larger
;
; As this is an early release, feel free to email me any problems or suggestions to gunther_oz@hotmail.com


; set up the basics
(define (script-fu-radial-blur
				img
				drawable
				amount
				feather
				radius
				posx
				posy
)

; undo grouping start
(begin
(gimp-undo-push-group-start img)

; make a feathered elliptical selection centred on the x,y coordinate
(gimp-ellipse-select img (- posx radius) (- posy radius) (* radius 2) (* 
radius 2) 2 1 0 0)
; invert the selection
(gimp-selection-invert img)

; feather the selction
(gimp-selection-feather img feather)

; gaussian blur it
(plug-in-gauss-iir 1 img drawable amount amount amount)

; clear the visible elliptical selection
(gimp-selection-clear img)

)
; undo grouping finish
(gimp-undo-push-group-end img)
(gimp-displays-flush)
    )

(script-fu-register "script-fu-radial-blur"
"<Image>/Script-Fu/Radial Blur..."
"Add a radially fading blur at a specified location."
"Gunther"
"gunther_oz@hotmail.com"
"2003"
"RGB*, GRAY*"
SF-IMAGE "Image" 0
SF-DRAWABLE "drawable" 0
SF-ADJUSTMENT _"Blur Amount" '(20 0 40 1 2 0 0)
SF-ADJUSTMENT _"Feather" '(20 0 100 1 2 0 0)
SF-ADJUSTMENT _"Exclusion Radius" '(20 0 8000 1 2 0 1)
SF-ADJUSTMENT _"Centre X" '(60 1 8000 1 10 0 1)
SF-ADJUSTMENT _"Centre Y" '(60 1 8000 1 10 0 1)
)